package com.yiqi.core.service.impl;

import java.util.List;

import com.yiqi.common.enums.SourceType;
import com.yiqi.common.utils.DateUtils;
import com.yiqi.common.utils.SecurityUtils;
import com.yiqi.core.domain.vo.GoodsSkuStockRecordVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.yiqi.core.mapper.GoodsSkuStockRecordMapper;
import com.yiqi.core.domain.GoodsSkuStockRecord;
import com.yiqi.core.service.IGoodsSkuStockRecordService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;

/**
 * 商品库存变更记录Service业务层处理
 *
 * @author ruoyi
 * @date 2023-11-29
 */
@Service
public class GoodsSkuStockRecordServiceImpl extends ServiceImpl<GoodsSkuStockRecordMapper,GoodsSkuStockRecord> implements IGoodsSkuStockRecordService {

    //<editor-folder desc="基础韩素">
    /**
     * 查询商品库存变更记录
     *
     * @param id 商品库存变更记录主键
     * @return 商品库存变更记录
     */
    @Override
    public GoodsSkuStockRecord selectGoodsSkuStockRecordById(Long id) {
        return baseMapper.selectGoodsSkuStockRecordById(id);
    }

    /**
     * 查询商品库存变更记录列表
     *
     * @param goodsSkuStockRecord 商品库存变更记录
     * @return 商品库存变更记录
     */
    @Override
    public List<GoodsSkuStockRecordVO> selectGoodsSkuStockRecordList(GoodsSkuStockRecord goodsSkuStockRecord) {
        goodsSkuStockRecord.setSourceType(SecurityUtils.getLoginUser().getSourceType());
        if(!SourceType.MANAGER.getCode().equals(SecurityUtils.getLoginUser().getSourceType())){
            goodsSkuStockRecord.setOrgId(SecurityUtils.getLoginUser().getOrgId());
        }
        return baseMapper.selectGoodsSkuStockRecordList(goodsSkuStockRecord);
    }

    /**
     * 新增商品库存变更记录
     *
     * @param goodsSkuStockRecord 商品库存变更记录
     * @return 结果
     */
    @Override
    public int insertGoodsSkuStockRecord(GoodsSkuStockRecord goodsSkuStockRecord) {
        goodsSkuStockRecord.setCreateTime(DateUtils.getNowDate());
        return baseMapper.insertGoodsSkuStockRecord(goodsSkuStockRecord);
    }

    /**
     * 修改商品库存变更记录
     *
     * @param goodsSkuStockRecord 商品库存变更记录
     * @return 结果
     */
    @Override
    public int updateGoodsSkuStockRecord(GoodsSkuStockRecord goodsSkuStockRecord) {
        goodsSkuStockRecord.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateGoodsSkuStockRecord(goodsSkuStockRecord);
    }

    /**
     * 批量删除商品库存变更记录
     *
     * @param ids 需要删除的商品库存变更记录主键
     * @return 结果
     */
    @Override
    public int deleteGoodsSkuStockRecordByIds(Long[] ids) {
        return baseMapper.deleteGoodsSkuStockRecordByIds(ids);
    }

    /**
     * 删除商品库存变更记录信息
     *
     * @param id 商品库存变更记录主键
     * @return 结果
     */
    @Override
    public int deleteGoodsSkuStockRecordById(Long id) {
        return baseMapper.deleteGoodsSkuStockRecordById(id);
    }


    //</editor-folder>

}
